---
layout: article
title: About
key: page-about
header:
  theme: dark
---

Did you ever wonder where you have all registered your email address? In the best case you have a Password manager where you keep all this info but in case you haven't here is your tool.

### Need help?

Please open a ticket [here](https://github.com/H3nkl3r/FindMyAccounts/issues/new?assignees=&labels=&template=help-me.yml&title=)

### Problems?

If you discovered a bug please report [here](https://github.com/H3nkl3r/FindMyAccounts/issues/new?assignees=&labels=&template=bug_report.yml&title=)

### Feature request?

Please let me know [here](https://github.com/H3nkl3r/FindMyAccounts/issues/new?assignees=&labels=&template=feature_request.yml&title=)
